@@ -59,13 +59,19 @@ GeometryTransformer::GeometryTransformer()
 	pruneEmptyGeometry(true),
 	preserveGeometryCollectionType(true),
 	preserveCollections(false),
-	preserveType(false)
+	preserveType(false),
+	skipTransformedInvalidInteriorRings(false)
 {}
 
 GeometryTransformer::~GeometryTransformer()
 {
 }
 
+void GeometryTransformer::setSkipTransformedInvalidInteriorRings(bool b)
+{
+	skipTransformedInvalidInteriorRings = b;
+}
+
 /*public*/
 auto_ptr<Geometry>
 GeometryTransformer::transform(const Geometry* nInputGeom)
@@ -283,6 +289,8 @@ GeometryTransformer::transformPolygon(
 
 		if ( ! dynamic_cast<LinearRing*>(hole.get()) )
 		{
+			if ( skipTransformedInvalidInteriorRings )
+			    continue;
 			isAllValidLinearRings = false;
 		}
 
